OutputsBuilder

Enum OutputsBuilder 

pub enum OutputsBuilder {
    Fixed(OutputHash),
    InputAddressed(BTreeSet<OutputName>),
}
A builder for outputs.

Variants



Fixed(OutputHash)

A fixed ouput



InputAddressed(BTreeSet<OutputName>)

Input addressed outputs

Implementations

Source

impl OutputsBuilder

pub fn names(&self) -> OutputNames<'_>

Gets an iterator over the names of the outputs, in sorted order.

pub fn into_names(self) -> IntoOutputNames

Convert this OutputsBuilder to an iterator over the names of the outputs, in sorted order.

pub fn len(&self) -> usize

Return count of names in this OutputsBuilder.

pub fn is_empty(&self) -> bool

Returns true if the builder contains no outputs.

pub fn is_single(&self) -> bool

Returns true if the builder contains a single output.

pub fn is_fixed(&self) -> bool

Returns true if the builder contains a fixed output.

pub fn contains(&self, name: &OutputName) -> bool

Returns true if the builder contains an output with the provided name.