UnverifiedOutputsBuilder

Struct UnverifiedOutputsBuilder 

pub struct UnverifiedOutputsBuilder(OutputsInner);
Builder for making unverified Outputs.

Even when not verifying the output path of a set of outputs, there are still invariants that must be upheld. But rather than checking all of them in one go, it is useful during construction to check each output as they are added and then do a final check when building the Outputs.

Examples

use nix_compat::derivation::{OutputName, UnverifiedOutputsBuilder};
use nix_compat::store_path::StorePath;

let mut builder = UnverifiedOutputsBuilder::new();
let out_sp : StorePath = "2vixb94v0hy2xc6p7mbnxxcyc095yyia-has-multi-out".parse().unwrap();
builder.try_insert(OutputName::out(), out_sp, None).unwrap();
let outputs = builder.try_build().unwrap();

Tuple Fields

0: OutputsInner

Implementations

Source

impl UnverifiedOutputsBuilder

pub const fn new() -> Self

Return an empty UnverifiedOutputsBuilder.

pub fn len(&self) -> usize

Returns the number of outputs

Examples
use nix_compat::derivation::{OutputName, UnverifiedOutputsBuilder};
use nix_compat::store_path::StorePath;

let mut builder = UnverifiedOutputsBuilder::new();
assert_eq!(builder.len(), 0);

let out_sp : StorePath = "2vixb94v0hy2xc6p7mbnxxcyc095yyia-has-multi-out".parse().unwrap();
builder.try_insert(OutputName::out(), out_sp, None).unwrap();
assert_eq!(builder.len(), 1);
pub fn is_empty(&self) -> bool

Returns true if there are not outputs defined in this builder.

Examples
use nix_compat::derivation::{OutputName, UnverifiedOutputsBuilder};
use nix_compat::store_path::StorePath;

let mut builder = UnverifiedOutputsBuilder::new();
assert!(builder.is_empty());

let out_sp : StorePath = "2vixb94v0hy2xc6p7mbnxxcyc095yyia-has-multi-out".parse().unwrap();
builder.try_insert(OutputName::out(), out_sp, None).unwrap();
assert!(!builder.is_empty());
pub fn is_input_addressed(&self) -> bool

Returns true if this is a set of input addressed outputs.

Examples
use nix_compat::derivation::{OutputName, UnverifiedOutputsBuilder};
use nix_compat::store_path::StorePath;

let mut a = UnverifiedOutputsBuilder::new();
assert!(!a.is_input_addressed());

let out_sp : StorePath = "2vixb94v0hy2xc6p7mbnxxcyc095yyia-has-multi-out".parse().unwrap();
a.try_insert(OutputName::out(), out_sp, None).unwrap();
assert!(a.is_input_addressed());

let bin_sp : StorePath = "2vixb94v0hy2xc6p7mbnxxcyc095yyib-has-multi-out-bin".parse().unwrap();
a.try_insert(OutputName::from_static("bin").unwrap(), bin_sp, None).unwrap();
assert!(a.is_input_addressed());

let mut b = UnverifiedOutputsBuilder::new();
let out_sp : StorePath = "2vixb94v0hy2xc6p7mbnxxcyc095yyia-has-multi-out".parse().unwrap();
b.try_insert(OutputName::out(), out_sp, Some(output_hash)).unwrap();
assert!(!b.is_input_addressed());
pub fn is_single(&self) -> bool

Returns true if this builder contains a single output called “out”

Examples
use nix_compat::derivation::{OutputName, UnverifiedOutputsBuilder};
use nix_compat::store_path::StorePath;

let mut a = UnverifiedOutputsBuilder::new();
let out_sp : StorePath = "2vixb94v0hy2xc6p7mbnxxcyc095yyia-has-multi-out".parse().unwrap();
a.try_insert(OutputName::out(), out_sp, None).unwrap();
assert!(a.is_single());

let bin_sp : StorePath = "2vixb94v0hy2xc6p7mbnxxcyc095yyib-has-multi-out-bin".parse().unwrap();
a.try_insert(OutputName::from_static("bin").unwrap(), bin_sp, None).unwrap();
assert!(!a.is_single());

let mut b = UnverifiedOutputsBuilder::new();
let out_sp : StorePath = "2vixb94v0hy2xc6p7mbnxxcyc095yyia-has-multi-out".parse().unwrap();
b.try_insert(OutputName::out(), out_sp, Some(output_hash)).unwrap();
assert!(b.is_single());
pub fn is_fixed(&self) -> bool

Returns true if this is a set of input addressed outputs.

Examples
use nix_compat::derivation::{OutputName, UnverifiedOutputsBuilder};
use nix_compat::store_path::StorePath;

let mut a = UnverifiedOutputsBuilder::new();
assert!(!a.is_fixed());

let out_sp : StorePath = "2vixb94v0hy2xc6p7mbnxxcyc095yyia-has-multi-out".parse().unwrap();
a.try_insert(OutputName::out(), out_sp, None).unwrap();
assert!(!a.is_fixed());

let mut b = UnverifiedOutputsBuilder::new();
let out_sp : StorePath = "2vixb94v0hy2xc6p7mbnxxcyc095yyia-has-multi-out".parse().unwrap();
b.try_insert(OutputName::out(), out_sp, Some(output_hash)).unwrap();
assert!(b.is_fixed());
pub fn contains_key(&self, name: &OutputName) -> bool

Returns true if the outputs contains an output with the specified name.

pub fn get(&self, name: &OutputName) -> Option<&StorePath>

Returns a reference to the StorePath corresponding to the provided name.

pub fn names(&self) -> OutputNames<'_>

Gets an iterator over the names of the outputs, in sorted order.

pub fn into_names(self) -> IntoOutputNames

Consume this builder and return an iterator over the names of the outputs, in sorted order.

pub fn iter(&self) -> Iter<'_>

Gets an iterator over the entries of the outputs, sorted by name.

pub fn store_paths(&self) -> impl Iterator<Item = &StorePath>

Gets an iterator over the StorePath values of the outputs, in order by name.

pub fn try_insert( &mut self, output_name: OutputName, output_path: StorePath, output_hash: Option<OutputHash>, ) -> Result<(), OutputsError>

Try to insert a new output with the provided values and an error if this violates the invariants.

pub fn try_build(self) -> Result<Outputs, OutputsError>

Consume this builder and return the built Outputs or an error if not possible.