DerivationBuilder

Struct DerivationBuilder 

pub struct DerivationBuilder {
    pub arguments: Vec<String>,
    pub command: String,
    pub environment: BTreeMap<String, BString>,
    pub input_derivations: BTreeMap<StorePath, BTreeSet<OutputName>>,
    pub input_sources: BTreeSet<StorePath>,
    pub outputs: OutputsBuilder,
    pub system: String,
}
Builder for Derivation and UnverifiedDerivation.

This helps to build either a Derivation or a UnverifiedDerivation from its component fields.

Since both Derivation and UnverifiedDerivation are immutable this builder is needed to construct them from scratch.

The fields are public so that they can be mutated without any getters and setters. The fields don’t know about output paths for a derivation, only output names and whether it’s a FOD.

Once the fields are populated:

Validation

When building a Derivation or an UnverifiedDerivation the following things are checked:

  • StorePath of input derivations end in .drv.
  • system is not empty.
  • builder is not empty.
  • no environment variable name is empty.

In addition, if producing a Derivation, all of its invariants are checked as well.

Fields

arguments: Vec<String>

Command line arguments to builder

command: String

Command to execute. This is usually a path to bash.

NOTE: This is called builder in cppnix and in Nix code.

environment: BTreeMap<String, BString>

Environment variables to include in build environmennt.

input_derivations: BTreeMap<StorePath, BTreeSet<OutputName>>

Map from drv path to output names used from this derivation.

input_sources: BTreeSet<StorePath>

Plain store paths of additional inputs.

outputs: OutputsBuilder

Builder for the outputs of this derivation.

system: String

System used to build this derivation.

Implementations

Source

impl DerivationBuilder

pub(super) fn serialize_with_replacements<'a, E, EK, EV, O, I, ID>( &self, writer: &mut impl Write, environment: E, outputs: O, input_derivations_sorted: I, ) -> Result<(), Error>
where E: IntoIterator<Item = (EK, EV)>, EK: AsRef<[u8]>, EV: AsRef<[u8]>, O: AtermWriteable, I: Iterator<Item = (ID, &'a BTreeSet<OutputName>)>, ID: AtermWriteable,

Like serialize, but allows replacing the environment, outputs and input_derivations for hash calculations.

This is used to render the ATerm representation of a Derivation “modulo fixed-output derivations”.

The passed environment, outputs and input_derivations MUST be sorted.

Source

impl DerivationBuilder

pub(super) fn hash_derivation_modulo_with_outputs<O, L, E, EK, EV>( &self, environment: E, outputs: &O, lookup: L, ) -> Result<Sha256, DerivationError>

Calculate HDM with provided environment variable and output replacements.

fn hash_derivation_modulo<L>( &self, lookup: L, ) -> Result<Sha256, DerivationError>

pub fn calculate_outputs<L>( &self, name: &str, lookup: L, ) -> Result<Outputs, DerivationError>

Calculate and return Outputs for this DerivationBuilder.

This will also ensure that the OutputsBuilder is valid, and that the provided name can be combined with the name of the output to produce a valid StorePath.

To calculate the outputs paths for input addressed outputs we need to lookup the hash derivation modulo of all input derivations, which is done using the provided HashDerivationModuloLookup.

Internally this calls store_path::build_ca_path or store_path::build_output_path, depending on output type, to actually make the StorePath.

pub fn build<L>( self, name: &str, lookup: L, ) -> Result<Derivation, DerivationError>

Consume this builder and return the built Derivation if possible.

This will build the validated and full Derivation using the data from this DerivationBuilder, the provided name and provided HashDerivationModuloLookup.

pub fn build_unverified( self, outputs: Outputs, ) -> Result<UnverifiedDerivation, DerivationError>

Consume this builder and return a UnverifiedDerivation with the provided outputs.

This will validate and update environment variables for outputs to their store paths.

fn validate(&self) -> Result<(), DerivationError>

Validate the fields of this builder.