pub struct OutputName(SmolStr);Expand description
A derivation output name.
This is a derivation output name, so the ‘out’ or ‘bin’ bit that has been verified to not contain invalid characters.
Output names may also not be empty or be called drv.
Tuple Fields
0: SmolStrImplementations
Sourceimpl OutputName
impl OutputName
pub fn as_str(&self) -> &str
Sourcepub fn from_static(s: &'static str) -> Result<Self, ParseOutputNameError>
pub fn from_static(s: &'static str) -> Result<Self, ParseOutputNameError>
Tries to construct from a &’static str.
pub const fn out() -> Self