pub enum OutputSpec {
All,
Named(BTreeSet<OutputName>),
}Expand description
An output selection spec.
This is either all outputs (formatted as ‘*’ when displaying or parsing) or
a set of OutputName with the outputs that is to be selected.
This is used in super::DerivedPath to perform selection of the outputs to make
sure, while building, are valid or substituted.
Variants
All
Named(BTreeSet<OutputName>)
Implementations
Sourceimpl OutputSpec
impl OutputSpec
pub fn single(output_name: OutputName) -> Self