pub struct OutputName(pub(crate) String);Expand description
A derivation output name.
This is a derivation output name, so the ‘out’ or ‘bin’ bit that has been verified to not contain invalid characters.
Tuple Fields
0: StringImplementations
Sourceimpl OutputName
impl OutputName
Sourcepub fn is_default(&self) -> bool
pub fn is_default(&self) -> bool
Returns true if this output name is the default of out.