pub struct BasicDerivation {
pub outputs: Outputs,
pub input_sources: BTreeSet<StorePath>,
pub system: String,
pub command: String,
pub arguments: Vec<String>,
pub environment: BTreeMap<String, BString>,
}Available on crate feature
daemon only.Fields
outputs: Outputsinput_sources: BTreeSet<StorePath>system: Stringcommand: Stringarguments: Vec<String>environment: BTreeMap<String, BString>Trait Implementations
Sourceimpl Clone for BasicDerivation
impl Clone for BasicDerivation
Sourcefn clone(&self) -> BasicDerivation
fn clone(&self) -> BasicDerivation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BasicDerivation
impl Debug for BasicDerivation
Sourceimpl NixDeserialize for BasicDerivation
impl NixDeserialize for BasicDerivation
Sourceimpl NixSerialize for BasicDerivation
impl NixSerialize for BasicDerivation
Sourceimpl PartialEq for BasicDerivation
impl PartialEq for BasicDerivation
Sourcefn eq(&self, other: &BasicDerivation) -> bool
fn eq(&self, other: &BasicDerivation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<BasicDerivation> for UnverifiedDerivation
impl TryFrom<BasicDerivation> for UnverifiedDerivation
Sourcetype Error = DerivationError
type Error = DerivationError
The type returned in the event of a conversion error.
impl Eq for BasicDerivation
impl StructuralPartialEq for BasicDerivation