pub enum CAHash {
Flat(NixHash),
Nar(NixHash),
Text([u8; 32]),
}Expand description
A Nix CAHash describes a content-addressed hash of a path.
The way Nix prints it as a string is a bit confusing, but there’s essentially
three modes, Flat, Nar and Text.
Flat and Nar support all 4 algos that NixHash supports
(sha1, md5, sha256, sha512), Text only supports sha256.
Variants
Implementations
Sourceimpl CAHash
impl CAHash
pub fn hash(&self) -> Cow<'_, NixHash>
pub fn mode(&self) -> HashMode
Sourcepub fn from_nix_hex_str(s: &str) -> Option<Self>
pub fn from_nix_hex_str(s: &str) -> Option<Self>
Constructs a CAHash from the textual representation, which is one of the three:
text:sha256:$nixbase32sha256digestfixed:r:$algo:$nixbase32digestfixed:$algo:$nixbase32digest
These formats are used in NARInfo, for example.