pub fn make_validity_registration<'a, W: Write, E: Iterator<Item = (&'a StorePathRef<'a>, R)>, R: Iterator<Item = &'a StorePathRef<'a>> + ExactSizeIterator + 'a>(
w: &mut W,
elems: E,
) -> ResultExpand description
Produces the format that Nix calls “makeValidityRegistration” and describes as:
“A string accepted by decodeValidPathInfo() that registers the specified paths as valid.”
Explained differently, this is the text format used in exportReferencesGraph,
in the non-structured attrs case, which can be passed to nix-store --register-validity.
We don’t implement the showDerivers and showHash functionality,
as that doesn’t seem to be used for exportReferenceGraph.