StorePath

Struct StorePath 

pub struct StorePath {
    digest: [u8; 20],
    name: SmolStr,
}
Represents a path in the Nix store (a direct child of STORE_DIR).

It consists of a digest (20 bytes), and a name, which is a string. The name may only contain ASCII alphanumeric, or one of the following characters: -, _, ., +, ?, =. The name is usually used to describe the pname and version of a package. Derivation paths can also be represented as store paths, their names just end with the .drv prefix.

A StorePath does not encode any additional subpath “inside” the store path.

Fields

digest: [u8; 20]name: SmolStr

Implementations

Source

impl StorePath

pub fn as_ref(&self) -> StorePathRef<'_>

Source

impl StorePath

pub fn digest(&self) -> &[u8; 20]

pub fn name(&self) -> &str

pub fn from_bytes(s: &[u8]) -> Result<Self, ParseStorePathError>

Construct a StorePath by passing the $digest-$name string that comes after STORE_DIR_WITH_SLASH.

pub fn from_name_and_digest( name: &str, digest: &[u8], ) -> Result<Self, ParseStorePathError>

Construct a StorePath from a name and digest. The name is validated, and the digest checked for size.

pub fn from_name_and_digest_fixed( name: &str, digest: [u8; 20], ) -> Result<Self, ParseStorePathError>

Construct a StorePathRef from a name and digest of correct length. The name is validated.

pub fn from_absolute_path(s: &[u8]) -> Result<Self, ParseStorePathError>

Construct a StorePathRef from an absolute store path string. This is equivalent to calling StorePathRef::from_bytes, but stripping the STORE_DIR_WITH_SLASH prefix before.

pub fn from_absolute_path_full<P>( path: &P, ) -> Result<(Self, &Path), ParseStorePathError>
where P: AsRef<Path> + ?Sized,

Decompose a string into a StorePathRef and a std::path::Path containing the rest of the path, or an error.

pub fn to_absolute_path(&self) -> String

Returns as an absolute store path (prefixed with STORE_DIR_WITH_SLASH).

pub fn as_absolute_path_fmt<'a>(&'a self) -> impl Display + 'a

Returns a formatter writing an absolute store path (prefixed with STORE_DIR_WITH_SLASH).