OutputHash

Struct OutputHash 

pub struct OutputHash {
    pub mode: OutputHashMode,
    pub hash: NixHash,
}
Represents the information about the hash of a single-output FOD. We store it in a OutputHashMode and NixHash. The serde model uses a different format, as we want to emit the same JSON: There we use hashAlgo and hash:

  • hashAlgo: optional r: prefix (for recursive), followed by hash algo identifier (sha1, sha256, sha512, md5)
  • hash: hexlower-encoded digest

Fields

mode: OutputHashModehash: NixHash

Implementations

Source

impl OutputHash

pub fn from_mode_algo_and_digest( mode_and_algo: &str, digest: impl AsRef<[u8]>, ) -> Result<Self, Error>

Construct from a string containing the algo (with an optional r: prefix), and a digest.

pub const fn as_mode_and_algo_str(&self) -> &'static str

Returns the OutputHashMode prefix str and the algo, concatenated. This is used in the ATerm representation.