pub struct UnverifiedDerivation {
builder: DerivationBuilder,
outputs: Outputs,
}Expand description
A derivation with its output paths filled out but not verified.
This is used for working with serialized versions of the derivation
without having to go through the hash derivation modulo verification
required by Derivation.
UnverifiedDerivation has getters for values, is not mutable and does
have output paths defined using Outputs. Those output paths are
possibly loaded from somewhere else and are not guaranteed to have been
verified to match the content of the derivation. When a derivation is
deserialized from either ATerm format or via serde this is the returned type.
Fields
builder: DerivationBuilderoutputs: OutputsImplementations
Sourceimpl UnverifiedDerivation
impl UnverifiedDerivation
Sourcepub fn verify<L>(
self,
name: &str,
lookup_fn: L,
) -> Result<Derivation, DerivationError>where
L: HashDerivationModuloLookup,
pub fn verify<L>(
self,
name: &str,
lookup_fn: L,
) -> Result<Derivation, DerivationError>where
L: HashDerivationModuloLookup,
Verify and consume this UnverifiedDerivation and return the Derivation.
It requires the name and lookup function to be passed in, as it verifies the outputs to have been calculated correctly and also calculates the drvPath.
Sourcepub fn serialize(&self, writer: &mut impl Write) -> Result<(), Error>
pub fn serialize(&self, writer: &mut impl Write) -> Result<(), Error>
write the Derivation to the given std::io::Write, in ATerm format.
The only errors returned are from the passed in writer.
Sourcepub fn to_aterm_bytes(&self) -> Vec<u8> ⓘ
pub fn to_aterm_bytes(&self) -> Vec<u8> ⓘ
return the ATerm serialization.
Sourcepub fn from_aterm_bytes(b: &[u8]) -> Result<Self, Error<&[u8]>>
pub fn from_aterm_bytes(b: &[u8]) -> Result<Self, Error<&[u8]>>
Parse an Derivation in ATerm serialization, and validate it passes our set of validations. This one does not validate output store paths to be calculated correctly.
Sourcepub fn calculate_derivation_path(
&self,
name: &str,
) -> Result<StorePath, DerivationError>
pub fn calculate_derivation_path( &self, name: &str, ) -> Result<StorePath, DerivationError>
Calculate and return the drv path of this UnverifiedDerivation.
The drv path is calculated by invoking store_path::build_text_path, using
the provided name with a .drv suffix added. All input_sources and
keys of input_derivations are used as references. And the ATerm string of
the UnverifiedDerivation is used as content.
Sourcepub fn fod_digest(&self) -> Option<Sha256>
pub fn fod_digest(&self) -> Option<Sha256>
Returns the FOD digest, if the derivation is fixed-output, or None if it’s not.
Sourcepub fn hash_derivation_modulo<L>(
&self,
lookup: L,
) -> Result<Sha256, DerivationError>where
L: HashDerivationModuloLookup,
pub fn hash_derivation_modulo<L>(
&self,
lookup: L,
) -> Result<Sha256, DerivationError>where
L: HashDerivationModuloLookup,
Calculates the hash derivation module of this UnverifiedDerivation.
Sourcepub fn recalculate_outputs<L>(
&self,
name: &str,
lookup: L,
) -> Result<Outputs, DerivationError>where
L: HashDerivationModuloLookup,
pub fn recalculate_outputs<L>(
&self,
name: &str,
lookup: L,
) -> Result<Outputs, DerivationError>where
L: HashDerivationModuloLookup,
Recalculate and return the Outputs of this UnverifiedDerivation.
Sourcepub fn into_parts(self) -> (DerivationBuilder, Outputs)
pub fn into_parts(self) -> (DerivationBuilder, Outputs)
Split this UnverifiedDerivation into its constituent parts.
Sourcepub fn command(&self) -> &str
pub fn command(&self) -> &str
Return builder to execute.
This is usually a path to bash.
NOTE: This is called builder in cppnix and in Nix code.
Sourcepub fn environment(&self) -> &BTreeMap<String, BString>
pub fn environment(&self) -> &BTreeMap<String, BString>
Return environment variables to include in build environmennt.
Sourcepub fn input_derivations(&self) -> &BTreeMap<StorePath, BTreeSet<OutputName>>
pub fn input_derivations(&self) -> &BTreeMap<StorePath, BTreeSet<OutputName>>
Map from drv path to output names used from this derivation.
Sourcepub fn input_sources(&self) -> &BTreeSet<StorePath>
pub fn input_sources(&self) -> &BTreeSet<StorePath>
Return plain store paths of additional inputs.