pub(crate) fn write_field<S: AsRef<[u8]>>(
writer: &mut impl Write,
s: S,
escape: bool,
) -> Result<()>Expand description
Write a string s as a quoted field to the writer.
The escape argument controls whether escaping will be skipped.
This is the case if s is known to only contain characters that need no
escaping.