pub enum DerivedPath {
Opaque(StorePath<String>),
Built {
drv_path: StorePath<String>,
outputs: OutputSpec,
},
}Expand description
A deriving path.
Deriving paths are a way to refer to store objects that may or may not yet be realised. There are two forms: - opaque: just a store path. - built: a pair of a store path to a store derivation and an output name.
See: https://nix.dev/manual/nix/latest/store/derivation/#deriving-path
Variants
Implementations
Sourceimpl DerivedPath
impl DerivedPath
pub fn into_legacy_format(self) -> LegacyDerivedPath
pub fn as_legacy_format(&self) -> &LegacyDerivedPath