pub struct StorePathRef<'a> {
digest: [u8; 20],
name: &'a str,
}Expand description
Like StorePath, but with a &str for the name.
Fields
digest: [u8; 20]name: &'a strImplementations
Sourceimpl<'a> StorePathRef<'a>
impl<'a> StorePathRef<'a>
pub fn digest(&self) -> &[u8; 20]
pub fn name(&self) -> &'a str
pub fn to_owned(&self) -> StorePath
Sourcepub fn from_bytes(s: &'a [u8]) -> Result<Self, ParseStorePathError>
pub fn from_bytes(s: &'a [u8]) -> Result<Self, ParseStorePathError>
Construct by passing the $digest-$name string that comes after
STORE_DIR_WITH_SLASH.
Sourcepub fn from_name_and_digest(
name: &'a str,
digest: &[u8],
) -> Result<Self, ParseStorePathError>
pub fn from_name_and_digest( name: &'a str, digest: &[u8], ) -> Result<Self, ParseStorePathError>
Construct from a name and digest. The name is validated, and the digest checked for size.
Sourcepub fn from_name_and_digest_fixed(
name: &'a str,
digest: [u8; 20],
) -> Result<Self, ParseStorePathError>
pub fn from_name_and_digest_fixed( name: &'a str, digest: [u8; 20], ) -> Result<Self, ParseStorePathError>
Construct from a name and digest of correct length. The name is validated.
Sourcepub fn from_absolute_path(s: &'a [u8]) -> Result<Self, ParseStorePathError>
pub fn from_absolute_path(s: &'a [u8]) -> Result<Self, ParseStorePathError>
Construct from an absolute store path string. This is equivalent to calling StorePathRef::from_bytes, but stripping the STORE_DIR_WITH_SLASH prefix before.
Sourcepub fn from_absolute_path_full<'p, P>(
path: &'p P,
) -> Result<(Self, &'p Path), ParseStorePathError>
pub fn from_absolute_path_full<'p, P>( path: &'p P, ) -> Result<(Self, &'p Path), ParseStorePathError>
Decompose a string into a StorePathRef and a std::path::Path containing the rest of the path, or an error.
Sourcepub fn to_absolute_path(&self) -> String
pub fn to_absolute_path(&self) -> String
Returns as an absolute store path (prefixed with STORE_DIR_WITH_SLASH).
Sourcepub fn as_absolute_path_fmt(&'a self) -> impl Display + 'a
pub fn as_absolute_path_fmt(&'a self) -> impl Display + 'a
Returns a formatter writing an absolute store path (prefixed with STORE_DIR_WITH_SLASH).