fn build_store_path_from_fingerprint_parts<'n>(
ty: impl Display,
inner_digest: &Sha256,
name: &'n str,
) -> Result<StorePathRef<'n>, ParseStorePathError>Expand description
This builds a store path from fingerprint parts.
This is called from build_text_path, build_output_path and build_ca_path to assemble the final path.
Using the inputs, it creates a fingerprint, hashes and compresses it,
then uses the passed name to create a store path.
If that name doesn’t match store path name requirements, the error is
passed along.